@@ -1,5 +1,5 @@
-/* libctl: flexible Guile-based control files for scientific software 
- * Copyright (C) 1998-2012 Massachusetts Institute of Technology and Steven G. Johnson
+/* libctl: flexible Guile-based control files for scientific software
+ * Copyright (C) 1998-2014 Massachusetts Institute of Technology and Steven G. Johnson
  *
  * This file may be used without restriction.  It is in the public
  * domain, and is NOT restricted by the terms of any GNU license.
@@ -8,7 +8,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * Steven G. Johnson can be contacted at stevenj@alum.mit.edu.
  */
 
@@ -54,7 +54,7 @@ int libctl_quiet = 0;
    Also return, in spec_file_loaded, whether we have loaded
    the specifications file due to a command-line arg.  Also return,
    in continue_run, whether or not to continue the run.  */
-int handle_args(int argc, char *argv[], 
+int handle_args(int argc, char *argv[],
 		boolean *spec_file_loaded, boolean *continue_run)
 {
      int i;
@@ -131,10 +131,14 @@ static int exists(const char *fname)
 static char *make_name(const char *for_dir, const char *for_base)
 {
      char *dir0, *dir, *base0, *base, *name = 0;
+     size_t ndir;
      dir0 = (char *) malloc(sizeof(char) * (strlen(for_dir) + 1));
      base0 = (char *) malloc(sizeof(char) * (strlen(for_base) + 1));
      strcpy(dir0, for_dir); dir = dirname(dir0);
-     if (strlen(dir)) {
+     ndir = strlen(dir);
+     if (ndir > 0) {
+       if (ndir > 5 && !strcmp(".libs", dir+ndir-5))
+          dir[ndir-5] = 0; /* ignore ".libs" directory suffix from libtool */
 	  strcpy(base0, for_base); base = basename(base0);
 	  name = (char *) malloc(sizeof(char) * (strlen(dir) + 1 +
 						 strlen(base) + 1));
@@ -180,6 +184,9 @@ void main_entry(
   int i;
   boolean spec_file_loaded, continue_run;
   SCM interactive;
+#ifdef HAVE_NO_GH
+  (void) main_entry_data; /* unused */
+#endif
 
   /* Notify Guile of functions that we are making callable from Scheme.
      These are defined in the specifications file, from which the
@@ -196,16 +203,16 @@ void main_entry(
 
 #ifdef HAVE_NLOPT
   /* Export the nlopt minimization routine, if available: */
-  gh_new_procedure ("nlopt-minimize", (SCM (*)(void)) nlopt_minimize_scm, 
+  gh_new_procedure ("nlopt-minimize", (SCM (*)(void)) nlopt_minimize_scm,
 		    8, 0, 1);
 #endif
 
   /* Export the adaptive integration routines: */
-  gh_new_procedure ("adaptive-integration", 
+  gh_new_procedure ("adaptive-integration",
 		    (SCM (*)(void)) adaptive_integration_scm, 6, 0, 0);
 
 #ifdef CTL_HAS_COMPLEX_INTEGRATION
-  gh_new_procedure ("cadaptive-integration", 
+  gh_new_procedure ("cadaptive-integration",
 		    (SCM (*)(void)) cadaptive_integration_scm, 6, 0, 0);
 #endif
 
@@ -256,7 +263,7 @@ void main_entry(
   for (; i < argc; ++i) {
     if (strchr(argv[i],'=')) {
       char *eq;
-      char *definestr = (char*) malloc(sizeof(char) * (strlen("(define ") + 
+      char *definestr = (char*) malloc(sizeof(char) * (strlen("(define ") +
 						       strlen(argv[i]) + 2));
       if (!definestr) {
 	   fprintf(stderr, __FILE__ ": out of memory!\n");
