@@ -1,5 +1,5 @@
 /* libctl: flexible Guile-based control files for scientific software
- * Copyright (C) 1998-2014 Massachusetts Institute of Technology and Steven G. Johnson
+ * Copyright (C) 1998-2019 Massachusetts Institute of Technology and Steven G. Johnson
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -39,6 +39,14 @@
 #  define MATERIAL_TYPE void*
 #endif
 
+/* Where possible (e.g. for gcc >= 3.1), enable a compiler warning
+   for code that uses a deprecated function */
+#if defined(__GNUC__) && (__GNUC__ > 3 || (__GNUC__==3 && __GNUC_MINOR__ > 0))
+#  define CTLGEOM_DEPRECATED __attribute__((deprecated))
+#else
+#  define CTLGEOM_DEPRECATED
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif                          /* __cplusplus */
@@ -51,13 +59,16 @@ extern void display_geometric_object_info(int indentby, geometric_object o);
 #endif
 
 extern void geom_initialize(void);
-extern void geom_fix_object(GEOMETRIC_OBJECT o);
+extern void geom_fix_object_ptr(GEOMETRIC_OBJECT *o);
+extern void geom_fix_object(GEOMETRIC_OBJECT o) CTLGEOM_DEPRECATED;
 extern void geom_fix_objects(void);
-extern void geom_fix_objects0(GEOMETRIC_OBJECT_LIST geometry);
+extern void geom_fix_objects0(GEOMETRIC_OBJECT_LIST geometry) CTLGEOM_DEPRECATED;
+extern void geom_fix_object_list(GEOMETRIC_OBJECT_LIST geometry);
 extern void geom_fix_lattice(void);
 extern void geom_fix_lattice0(LATTICE *L);
 extern void geom_cartesian_lattice(void);
 extern void geom_cartesian_lattice0(LATTICE *L);
+extern double geom_object_volume(GEOMETRIC_OBJECT o);
 extern boolean point_in_objectp(vector3 p, GEOMETRIC_OBJECT o);
 extern boolean point_in_periodic_objectp(vector3 p, GEOMETRIC_OBJECT o);
 extern boolean point_in_fixed_objectp(vector3 p, GEOMETRIC_OBJECT o);
@@ -83,6 +94,8 @@ GEOMETRIC_OBJECT object_of_point0(GEOMETRIC_OBJECT_LIST geometry, vector3 p,
 GEOMETRIC_OBJECT object_of_point(vector3 p, vector3 *shiftby);
 vector3 shift_to_unit_cell(vector3 p);
 extern matrix3x3 square_basis(matrix3x3 lattice_basis, vector3 size);
+extern void ctl_printf(const char *fmt, ...);
+extern void (*ctl_printf_callback)(const char *s);
 
 typedef struct {
      vector3 low, high;
@@ -147,10 +160,18 @@ GEOMETRIC_OBJECT make_block(MATERIAL_TYPE material, vector3 center,
 GEOMETRIC_OBJECT make_ellipsoid(MATERIAL_TYPE material, vector3 center,
 				vector3 e1, vector3 e2, vector3 e3,
 				vector3 size);
+
+// prism with `center` field computed automatically from vertices, height, axis
 GEOMETRIC_OBJECT make_prism(MATERIAL_TYPE material,
 			    const vector3 *vertices, int num_vertices,
 			    double height, vector3 axis);
 
+// as make_prism, but with a rigid translation so that the prism is centered at center
+GEOMETRIC_OBJECT make_prism_with_center(MATERIAL_TYPE material, vector3 center,
+                                        const vector3 *vertices, int num_vertices,
+                                        double height, vector3 axis);
+
+
 int vector3_nearly_equal(vector3 v1, vector3 v2, double tolerance);
 
 /**************************************************************************/
